<?php

namespace Edulab\College\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Edulab\College\Forms\Guardian as GuardianForm;
use Edulab\College\Http\Requests\GuardianResourceRequest;
use Edulab\College\Http\Resources\GuardianResource;
use Edulab\College\Http\Resources\GuardiansCollection;
use Edulab\College\Models\Guardian;
use Edulab\College\Actions\GuardianAction;
use Edulab\College\Actions\GuardianActions;


/**
 * Resource controller class for guardian.
 */
class GuardianResourceController extends BaseController
{

    /**
     * Initialize guardian resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = GuardianForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('edulab.college.modules'), 'college', guard_url('college'));
            return $next($request);
        });
    }

    /**
     * Display a list of guardian.
     *
     * @return Response
     */
    public function index(GuardianResourceRequest $request)
    {
        $request = $request->all();
        $page = GuardianActions::run('paginate', $request);

        $data = new GuardiansCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('college::guardian.names'))
            ->view('college::guardian.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display guardian.
     *
     * @param Request $request
     * @param Model   $guardian
     *
     * @return Response
     */
    public function show(GuardianResourceRequest $request, Guardian $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new GuardianResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('college::guardian.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('college::guardian.show')
            ->output();
    }

    /**
     * Show the form for creating a new guardian.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(GuardianResourceRequest $request, Guardian $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new GuardianResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('college::guardian.name'))
            ->view('college::guardian.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new guardian.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(GuardianResourceRequest $request, Guardian $model)
    {
        try {
            $request = $request->all();
            $model = GuardianAction::run('store', $model, $request);
            $data = new GuardianResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('college::guardian.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('college/guardian/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/college/guardian'))
                ->redirect();
        }

    }

    /**
     * Show guardian for editing.
     *
     * @param Request $request
     * @param Model   $guardian
     *
     * @return Response
     */
    public function edit(GuardianResourceRequest $request, Guardian $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new GuardianResource($model);
        // return view('college::guardian.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('college::guardian.name'))
            ->view('college::guardian.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the guardian.
     *
     * @param Request $request
     * @param Model   $guardian
     *
     * @return Response
     */
    public function update(GuardianResourceRequest $request, Guardian $model)
    {
        try {
            $request = $request->all();
            $model = GuardianAction::run('update', $model, $request);
            $data = new GuardianResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('college::guardian.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('college/guardian/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('college/guardian/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the guardian.
     *
     * @param Model   $guardian
     *
     * @return Response
     */
    public function destroy(GuardianResourceRequest $request, Guardian $model)
    {
        try {

            $request = $request->all();
            $model = GuardianAction::run('destroy', $model, $request);
            $data = new GuardianResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('college::guardian.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('college/guardian/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('college/guardian/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
