<?php

namespace Edulab\College\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Edulab\College\Events\CollegeAction as CollegeActionEvent;
use Edulab\College\Notifications\CollegeAction as CollegeActionNotification;
use Litepie\Actions\Concerns\AsAction;

class CollegeAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the CollegeActionEvent.
     *
     * @param   CollegeActionEvent  $event
     * @return mixed
     */
    public function handle(CollegeActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $college.
     *
     * @param   CollegeActionEvent  $event
     * @return void
     */
    public function create(CollegeActionEvent $event)
    {
        $client = $event->college->client;
        Notification::send($client, new CollegeActionNotification($event));
    }

    /**
     * Handle the CollegeActionEvent as a listener.
     *
     * @param   CollegeActionEvent  $event
     * @return mixed
     */
    public function asListener(CollegeActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   CollegeActionEvent  $event
     * @return bool
     */
    private function isAllowed(CollegeActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
