<?php

namespace Edulab\College\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Edulab\College\Events\CollegeWorkflow as CollegeWorkflowEvent;
use Edulab\College\Notifications\CollegeWorkflow as CollegeWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class CollegeWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(CollegeWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $college is submitted.
     *
     * @param CollegeWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(CollegeWorkflowEvent $event)
    {
        $client = $event->college->client;
        Notification::send($client, new CollegeWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $college is published.
     *
     * @param CollegeWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(CollegeWorkflowEvent $event)
    {
        $client = $event->college->client;
        Notification::send($client, new CollegeWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $college is approved.
     *
     * @param CollegeWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(CollegeWorkflowEvent $event)
    {
        $client = $event->college->client;
        Notification::send($client, new CollegeWorkflowNotification($event));
    }

    /**
     * Handles the $college workflow event as a listener.
     *
     * @param CollegeWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(CollegeWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
