<?php

namespace Edulab\College\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Edulab\College\Events\GuardianWorkflow as GuardianWorkflowEvent;
use Edulab\College\Notifications\GuardianWorkflow as GuardianWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class GuardianWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(GuardianWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $guardian is submitted.
     *
     * @param GuardianWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(GuardianWorkflowEvent $event)
    {
        $client = $event->guardian->client;
        Notification::send($client, new GuardianWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $guardian is published.
     *
     * @param GuardianWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(GuardianWorkflowEvent $event)
    {
        $client = $event->guardian->client;
        Notification::send($client, new GuardianWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $guardian is approved.
     *
     * @param GuardianWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(GuardianWorkflowEvent $event)
    {
        $client = $event->guardian->client;
        Notification::send($client, new GuardianWorkflowNotification($event));
    }

    /**
     * Handles the $guardian workflow event as a listener.
     *
     * @param GuardianWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(GuardianWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
