<?php

namespace Edulab\College\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Edulab\College\Events\TeacherAction as TeacherActionEvent;
use Edulab\College\Notifications\TeacherAction as TeacherActionNotification;
use Litepie\Actions\Concerns\AsAction;

class TeacherAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the TeacherActionEvent.
     *
     * @param   TeacherActionEvent  $event
     * @return mixed
     */
    public function handle(TeacherActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $teacher.
     *
     * @param   TeacherActionEvent  $event
     * @return void
     */
    public function create(TeacherActionEvent $event)
    {
        $client = $event->teacher->client;
        Notification::send($client, new TeacherActionNotification($event));
    }

    /**
     * Handle the TeacherActionEvent as a listener.
     *
     * @param   TeacherActionEvent  $event
     * @return mixed
     */
    public function asListener(TeacherActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   TeacherActionEvent  $event
     * @return bool
     */
    private function isAllowed(TeacherActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
