<?php

namespace Edulab\College\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Edulab\College\Models\College;

class CollegePolicy
{


    /**
     * Determine if the given user can view the college.
     *
     * @param Authenticatable $user
     * @param College $college
     *
     * @return bool
     */
    public function view(Authenticatable $user, College $college)
    {
        if ($authUser->canDo('college.college.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $college->is_owner;
    }

    /**
     * Determine if the given user can create a college.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('college.college.create');
    }

    /**
     * Determine if the given user can update the given college.
     *
     * @param Authenticatable $user
     * @param College $college
     *
     * @return bool
     */
    public function update(Authenticatable $user, College $college)
    {
        if ($user->canDo('college.college.edit') && $user->isAdmin()) {
            return true;
        }

        return $college->is_owner;
    }

    /**
     * Determine if the given user can delete the given college.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, College $college)
    {
        return $college->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
