<?php

namespace Edulab\College\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Edulab\College\Models\Guardian;

class GuardianPolicy
{


    /**
     * Determine if the given user can view the guardian.
     *
     * @param Authenticatable $user
     * @param Guardian $guardian
     *
     * @return bool
     */
    public function view(Authenticatable $user, Guardian $guardian)
    {
        if ($authUser->canDo('college.guardian.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $guardian->is_owner;
    }

    /**
     * Determine if the given user can create a guardian.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('college.guardian.create');
    }

    /**
     * Determine if the given user can update the given guardian.
     *
     * @param Authenticatable $user
     * @param Guardian $guardian
     *
     * @return bool
     */
    public function update(Authenticatable $user, Guardian $guardian)
    {
        if ($user->canDo('college.guardian.edit') && $user->isAdmin()) {
            return true;
        }

        return $guardian->is_owner;
    }

    /**
     * Determine if the given user can delete the given guardian.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Guardian $guardian)
    {
        return $guardian->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
