<?php

namespace Edulab\College\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Edulab\College\Models\Teacher;

class TeacherPolicy
{


    /**
     * Determine if the given user can view the teacher.
     *
     * @param Authenticatable $user
     * @param Teacher $teacher
     *
     * @return bool
     */
    public function view(Authenticatable $user, Teacher $teacher)
    {
        if ($authUser->canDo('college.teacher.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $teacher->is_owner;
    }

    /**
     * Determine if the given user can create a teacher.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('college.teacher.create');
    }

    /**
     * Determine if the given user can update the given teacher.
     *
     * @param Authenticatable $user
     * @param Teacher $teacher
     *
     * @return bool
     */
    public function update(Authenticatable $user, Teacher $teacher)
    {
        if ($user->canDo('college.teacher.edit') && $user->isAdmin()) {
            return true;
        }

        return $teacher->is_owner;
    }

    /**
     * Determine if the given user can delete the given teacher.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Teacher $teacher)
    {
        return $teacher->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
