<?php

namespace Edulab\College\Providers;

use Illuminate\Support\ServiceProvider;
use Edulab\College\Colleges;

class CollegeServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'college');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'college');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Edulab\College\Providers\AuthServiceProvider::class);
        $this->app->register(\Edulab\College\Providers\RouteServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('edulab.college', function($app)
        {
            return $this->app->make(College::class);
        });
    }

    /**
     * Merges user's and college's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'edulab.college'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/college.php', 'edulab.college.college'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/student.php', 'edulab.college.student'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/guardian.php', 'edulab.college.guardian'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/teacher.php', 'edulab.college.teacher'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['edulab.college'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('edulab/college')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/college')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/college')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
